@@ -7,6 +7,9 @@ extern "C"
 {
 #endif
 
+// forward declaration. This is in <netdnet/dn.h>.
+struct sockaddr_dn;
+
 struct	nodeent	{
 	char	*n_name;		/* name of node */
 	unsigned short n_addrtype;	/* node address type */
@@ -27,6 +30,11 @@ extern  struct  dn_naddr *getnodeadd(void);
 extern  struct  nodeent  *getnodebyaddr(const char *addr, int len, int type);
 extern  struct  nodeent  *getnodebyname(const char *name);
 
+extern  int               dnet_setobjhinum_handling(int handling, int min);
+extern  int               getobjectbyname(char * name);
+extern  int               getobjectbynumber(int number, char * name, size_t name_len);
+extern  int               dnet_checkobjectnumber(int num);
+
 extern  char             *getexecdev(void);
 extern  void              setnodeent(int);
 extern  void             *dnet_getnode(void);
@@ -50,21 +58,37 @@ extern void  init_daemon_logging(char *, char);
 extern void  dnetlog(int level, char *fmt, ...);
 #define DNETLOG(x) dnetlog x
 
+int dnet_priv_check(const char * file, const char * proc,
+                    const struct sockaddr_dn * local, const struct sockaddr_dn * remote);
+
 /* Used by dnet_ntop/dnet_pton */
 #define DNET_ADDRSTRLEN  8
     
 /*
  * Define DECnet object numerically.
  */
-#define DNOBJECT_FAL	17	/* file access listener */
-#define DNOBJECT_NICE	19	/* NICE */
-#define DNOBJECT_DTERM	23	/* DECnet remote terminals */
-#define DNOBJECT_MIRROR	25	/* DECnet mirror */
-#define DNOBJECT_EVR	26	/* DECnet event receiver */
-#define DNOBJECT_MAIL11	27	/* mail service */
-#define DNOBJECT_PHONE	29	/* DECnet phone utility */
-#define DNOBJECT_CTERM	42	/* DECnet command terminals */
-#define DNOBJECT_DTR	63	/* DECnet test receiver */
+#define DNOBJECT_FAL	(getobjectbyname("FAL"))	/* file access listener */
+#define DNOBJECT_NICE	(getobjectbyname("NICE"))	/* NICE */
+#define DNOBJECT_DTERM	(getobjectbyname("DTERM"))	/* DECnet remote terminals */
+#define DNOBJECT_MIRROR	(getobjectbyname("MIRROR"))	/* DECnet mirror */
+#define DNOBJECT_EVR	(getobjectbyname("EVR"))	/* DECnet event receiver */
+#define DNOBJECT_MAIL11	(getobjectbyname("MAIL11"))	/* mail service */
+#define DNOBJECT_PHONE	(getobjectbyname("PHONE"))	/* DECnet phone utility */
+#define DNOBJECT_CTERM	(getobjectbyname("CTERM"))	/* DECnet command terminals */
+#define DNOBJECT_DTR	(getobjectbyname("DTR"))	/* DECnet test receiver */
+
+/* Config for dnet_checkobjectnumber()/getobjectbyname()/getobjectbynumber() */
+#define DNOBJ_SEARCH_ENV "DECNET_OBJPROTO"
+#define DNOBJ_SEARCH_DEF "decnet"
+
+#define DNOBJ_HINUM_ENV "DECNET_OBJHINUM"
+#define DNOBJ_HINUM_DEF "error"
+
+#define DNOBJHINUM_RESET          -128
+#define DNOBJHINUM_ERROR          -1
+#define DNOBJHINUM_RETURN          0
+#define DNOBJHINUM_ZERO            1
+#define DNOBJHINUM_ALWAYSZERO      2
 
 /* Connect/Reject codes. These are my symbolic names, not DEC's */
 #define DNSTAT_REJECTED         0 /* Rejected by object */
